@@ -3,12 +3,14 @@ use 5.008;
 use strict;
 use warnings;
 use parent qw(Plack::Middleware::Debug::Base);
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
-sub process_response {
-    my ($self, $res, $env) = @_;
-    $self->content($self->render_hash($env));
+sub run {
+    my($self, $env, $panel) = @_;
+    $panel->content(sub { $self->render_hash($env) });
+    return;
 }
+
 1;
 __END__
 
