@@ -4,12 +4,13 @@ use strict;
 use warnings;
 use Config;
 use parent qw(Plack::Middleware::Debug::Base);
-our $VERSION = '0.03';
+our $VERSION = '0.05';
 
-sub process_request {
-    my ($self, $env) = @_;
-    $self->content($self->render_hash(\%Config));
+sub run {
+    my ($self, $env, $panel) = @_;
+    $panel->content($self->render_hash(\%Config));
 }
+
 1;
 __END__
 
